/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: CommonConfigurable.java,v 1.8 2004/02/08 02:43:01 vgritsenko Exp $
 */

package org.apache.xindice.client.xmldb;

import org.xmldb.api.base.Configurable;
import org.xmldb.api.base.XMLDBException;

import java.util.Hashtable;

/**
 * Base class to handle property managment within the API implementation.
 *
 * @version CVS $Revision: 1.8 $, $Date: 2004/02/08 02:43:01 $
 */
public abstract class CommonConfigurable implements Configurable {

    protected Hashtable config = null;

    /**
     * Constructor for the CommonConfigurable object
     */
    public CommonConfigurable() {
        config = new Hashtable();
    }

    /**
     * Constructor for the CommonConfigurable object
     * @param commonConfigurable from which the initial properties for this
     *        object are copied.
     */
    public CommonConfigurable(CommonConfigurable commonConfigurable) {
        config = new Hashtable(commonConfigurable.config);
    }

    /**
     * Sets a property value. If the property doesn't exist it is created, if it
     * does exist it is overwritten.
     *
     * @param name The Property name
     * @param value The new Property value
     * @exception XMLDBException
     */
    public void setProperty(String name, String value) throws XMLDBException {
        config.put(name, value);
    }

    /**
     * Gets the Property associated with name
     *
     * @param name The name of the property to retrieve.
     * @return The Property value
     * @exception XMLDBException
     */
    public String getProperty(String name) throws XMLDBException {
        return (String) config.get(name);
    }
}
