/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: QueryService.java,v 1.7 2004/02/08 02:43:02 vgritsenko Exp $
 */

package org.apache.xindice.client.xmldb.services;

import org.apache.xindice.client.xmldb.CommonConfigurable;
import org.apache.xindice.client.xmldb.XindiceCollection;

import org.xmldb.api.base.Collection;
import org.xmldb.api.base.ResourceSet;
import org.xmldb.api.base.Service;
import org.xmldb.api.base.XMLDBException;

import java.util.Hashtable;

/**
 * Abstract query service.
 *
 * Used to implemented both XUpdate and XPath query
 * service, as the interface for these queries on the XML-RPC API is more
 * or less identical.
 *
 * @author <a href="mailto:james.bates@amplexor.com">James Bates</a>
 * @version CVS $Revision: 1.7 $, $Date: 2004/02/08 02:43:02 $
 */
public abstract class QueryService extends CommonConfigurable implements Service {

    /* XPath or XUpdate. This property should be set by subclasses */
    protected String queryLang;

    /* Collection that this query service should query in */
    Collection collection;

    /* namespace bindings in use for this query */
    Hashtable nsMap = new Hashtable();

    public String getVersion() {

        return "1.0";
    }

    public String getName() {

        return queryLang + "QueryService";
    }

    public void setCollection(Collection collection) {

        this.collection = collection;
    }

    public ResourceSet queryResource(String name, String query)
            throws XMLDBException {

        return ((XindiceCollection) collection).query(name, queryLang, query, nsMap);
    }

    public void clearNamespaces() {

        nsMap.clear();
    }

    public String getNamespace(String prefix) {

        return (String) nsMap.get(prefix);
    }

    public void setNamespace(String prefix, String namespaceURI) {

        nsMap.put(prefix, namespaceURI);
    }

    public ResourceSet query(String query) throws XMLDBException {

        return ((XindiceCollection) collection).query(queryLang, query, nsMap);
    }

    public void removeNamespace(String prefix) throws XMLDBException {

        nsMap.remove(prefix);
    }

}
