/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: Container.java,v 1.6 2004/02/08 02:51:06 vgritsenko Exp $
 */

package org.apache.xindice.core;

import org.apache.xindice.core.data.Key;

import org.w3c.dom.Document;

/**
 * Container is a generic container for Key and Document pairs.
 *
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 02:51:06 $
 */
public interface Container {

    /**
     * getCollection returns the Collection that the Document contained
     * belongs to.
     *
     * @return The owner Collection
     */
    Collection getCollection();

    /**
     * getKey returns the Document Key.
     *
     * @return The Document Key
     */
    Key getKey();

    /**
     * getCanonicalName returns the canonical name for the contained
     * Document.
     * <br>
     * ex: /local/test/ocs/ytd
     *
     * @return The canonical name
     */
    String getCanonicalName() throws DBException;

    /**
     * getDocument returns the contained Document.
     *
     * @return The Document
     */
    Document getDocument();

    /**
     * rollback reloads the Document from the Collection.
     *
     * @return The Document
     */
    Document rollback() throws DBException;

    /**
     * delete removes the Document from the Collection.
     */
    void remove() throws DBException;

    /**
     * commit saves the Document in the Collection.
     */
    void commit() throws DBException;

    /**
     * commit replaces the Document in the Collection with the
     * specified Document.
     *
     * @param document The Document
     */
    void commit(Document document) throws DBException;
}

