/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: DBObserver.java,v 1.9 2004/02/08 02:51:06 vgritsenko Exp $
 */

package org.apache.xindice.core;

import org.apache.xindice.core.data.Key;
import org.apache.xindice.core.data.Record;
import org.apache.xindice.util.Configuration;

import org.w3c.dom.Document;

import java.util.Map;

/**
 * Observer for Xindice DB activities
 *
 * @version CVS $Revision: 1.9 $, $Date: 2004/02/08 02:51:06 $
 */
public abstract class DBObserver {

    private static final DBObserver NOOP = new DBObserver() {
        public void setDatabaseConfig(Database db, Map collections, Configuration cfg) {
        }

        public void setCollectionConfig(Collection col, Configuration cfg) {
        }

        public void flushDatabaseConfig(Database db, Configuration cfg) {
        }

        public void dropCollection(Collection col) {
        }

        public void createCollection(Collection col) {
        }

        public void putDocument(Collection col, Key key, Document document, boolean create) {
        }

        public void loadDocument(Collection col, Record record, Document document) {
        }

        public void dropDocument(Collection col, Key key) {
        }
    };

    private static DBObserver instance = NOOP;

    /**
     * Sets the default observer instance
     */
    public static void setInstance(DBObserver obs) {
        instance = (null == obs) ? NOOP : obs;
    }

    /**
     * Returns the observer instance, must be non-null
     */
    public static DBObserver getInstance() {
        return instance;
    }

    /**
     * Called after Database.setConfig()
     */
    public abstract void setDatabaseConfig(Database db, Map collections, Configuration cfg);

    /**
     * Called after Collection.setConfig()
     */
    public abstract void setCollectionConfig(Collection col, Configuration cfg);

    /**
     * Called after Database.flushConfig()
     */
    public abstract void flushDatabaseConfig(Database db, Configuration cfg);

    /**
     * Called before Collection.drop()
     */
    public abstract void dropCollection(Collection col) throws DBException;

    /**
     * Called after Collection.create()
     */
    public abstract void createCollection(Collection col) throws DBException;

    /**
     * Called after Collection.putDocument()
     */
    public abstract void putDocument(Collection col, Key key, Document document, boolean create) throws DBException;

    /**
     * Called after Collection.getDocument()
     */
    public abstract void loadDocument(Collection col, Record record, Document document) throws DBException;

    /**
     * Called before Collection.remove(key)
     */
    public abstract void dropDocument(Collection col, Key key) throws DBException;
}
