/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: Key.java,v 1.6 2004/02/08 02:49:44 vgritsenko Exp $
 */

package org.apache.xindice.core.data;

/**
 * Key extends Value by providing a hash value for the Key.
 *
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 02:49:44 $
 */
public final class Key extends Value {
    private int hash = 0;

    public Key(Value value) {
        super(value);
    }

    public Key(byte[] data) {
        super(data);
    }

    public Key(byte[] data, int pos, int len) {
        super(data, pos, len);
    }

    public Key(String data) {
        super(data);
    }

    // TODO: This has to be revisited
    private void calculateHash() {
        hash = 0;
        int pl = pos + len;
        for (int i = pos; i < pl; i++) {
            hash = (hash << 5) ^ data[i];
            hash = hash % 1234567891;
        }
        hash = Math.abs(hash);
    }

    public int getHash() {
        if (hash == 0) {
            calculateHash();
        }
        return hash;
    }

    public boolean equals(Value value) {
        if (value instanceof Key) {
            Key key = (Key) value;
            return getHash() == key.getHash() ? compareTo(key) == 0
                    : false;
        } else {
            return super.equals(value);
        }
    }

    public int hashCode() {
        return getHash();
    }

    public boolean equals(Object obj) {
        if (obj instanceof Key) {
            return equals((Key) obj);
        } else {
            return super.equals(obj);
        }
    }
}

