/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: RecordSet.java,v 1.5 2004/02/08 02:49:44 vgritsenko Exp $
 */

package org.apache.xindice.core.data;

import org.apache.xindice.core.DBException;

/**
 * RecordSet is an interface for iterating over a set of Records.
 * It is almost always returned by Filers.
 *
 * @version CVS $Revision: 1.5 $, $Date: 2004/02/08 02:49:44 $
 */
public interface RecordSet {

    /**
     * hasMoreRecords returns whether or not there are any Records
     * left in the set.
     *
     * @return Whether there are any more Records
     */
    boolean hasMoreRecords() throws DBException;

    /**
     * getNextRecord returns the next Record in the set.
     *
     * @return The next Record
     */
    Record getNextRecord() throws DBException;

    /**
     * getNextKey returns the next Record's Key, and skips the
     * RecordSet ahead to the next Record.
     *
     * @return The next Key
     */
    Key getNextKey() throws DBException;

    /**
     * getNextValue returns the next Record's Value, and skips the
     * RecordSet ahead to the next Record.
     *
     * @return The next Value
     */
    Value getNextValue() throws DBException;
}
