/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: Query.java,v 1.5 2004/02/08 02:50:37 vgritsenko Exp $
 */

package org.apache.xindice.core.query;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.data.Key;
import org.apache.xindice.core.data.NodeSet;
import org.apache.xindice.xml.NamespaceMap;

/**
 * Query represents a compiled (parsed and primed) query.
 *
 * @version CVS $Revision: 1.5 $, $Date: 2004/02/08 02:50:37 $
 */
public interface Query {

    /**
     * getQueryStyle returns the QueryStyle (ex: XPath) for this Query
     * instance.
     *
     * @return The Query style
     */
    String getQueryStyle();

    /**
     * getQueryContext returns the Collection context for this query.
     *
     * @return The Collection context
     */
    Collection getQueryContext();

    /**
     * getQueryString returns the String that was used to create the
     * Query instance.
     *
     * @return The Query String
     */
    String getQueryString();

    /**
     * getNamespaceMap returns the Map for prefixed namespace
     * resolution in relation to this Query.
     *
     * @return The namespace Map (if any)
     */
    NamespaceMap getNamespaceMap();

    /**
     * getKeySet returns the initial set of Keys for this Query.
     *
     * @return The initial Key set (if any)
     */
    Key[] getKeySet();

    /**
     * execute actually Executes the query and returns the resulting
     * NodeSet.
     *
     * @return The NodeSet
     */
    NodeSet execute() throws QueryException;


}
