/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: RPCMessageInterface.java,v 1.9 2004/02/19 03:05:15 vgritsenko Exp $
 */

package org.apache.xindice.server.rpc;

import org.apache.xindice.core.DBException;
import org.apache.xindice.core.Collection;
import org.apache.xindice.core.FaultCodes;
import org.apache.xmlrpc.XmlRpcException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.xmldb.api.base.ErrorCodes;
import org.xmldb.api.base.XMLDBException;

import java.util.Hashtable;

/**
 *
 * @version CVS $Revision: 1.9 $, $Date: 2004/02/19 03:05:15 $
 */
public final class RPCMessageInterface {

    private static final Log log = LogFactory.getLog(Collection.class);

    public static final String MESSAGE_PARAM = "message";

    public Hashtable run(Hashtable message) throws Exception {
        // The method determines what class we load to handle the message.
        String type = (String)message.get(MESSAGE_PARAM);
        try {
            RPCMessage handler = (RPCMessage) Class.forName("org.apache.xindice.server.rpc.messages." + type).newInstance();
            return handler.execute(message);
        } catch (XMLDBException e) {
            if (log.isDebugEnabled()) {
                log.debug("Exception while processing XmlRpc command " + type, e);
            }

            throw new XmlRpcException(e.errorCode * FaultCodes.MAX_CODE + e.vendorErrorCode, e.getMessage());
        } catch (DBException e) {
            if (log.isDebugEnabled()) {
                log.debug("Exception while processing XmlRpc command " + type, e);
            }

            throw new XmlRpcException(ErrorCodes.VENDOR_ERROR * FaultCodes.MAX_CODE + e.faultCode, e.getMessage());
        }
    }
}
