/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: ArgTokenizer.java,v 1.6 2004/02/08 02:57:35 vgritsenko Exp $
 */

package org.apache.xindice.tools;

import java.util.StringTokenizer;

/**
 * ArgTokenizer performs the difficult task of parsing
 * command-line arguments from various sources.
 *
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 02:57:35 $
 */
public final class ArgTokenizer {

    private int idx = 0;
    private String[] args;


    public ArgTokenizer(String[] args) {
        this.args = args;
    }

    public ArgTokenizer(String argString) {
        StringTokenizer st = new StringTokenizer(argString);
        args = new String[st.countTokens()];
        for (int i = 0; st.hasMoreTokens(); i++) {
            args[i] = st.nextToken();
        }
    }

    public boolean hasMoreTokens() {
        return idx < args.length;
    }

    public String nextSwitchToken() {
        if (hasMoreTokens()) {
            StringBuffer sb = new StringBuffer();
            sb.append(args[idx++]);
            while (hasMoreTokens()) {
                String nt = args[idx];
                if (!nt.startsWith("-")) {
                    sb.append(' ' + args[idx++]);
                }
                else
                    break;
            }
            return sb.toString();
        } else
            return "";
    }

    public String nextToken() {
        if (hasMoreTokens()) {
            return args[idx++];
        } else {
            return "";
        }
    }
}

