/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: AddCollection.java,v 1.11 2004/02/08 02:57:35 vgritsenko Exp $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.client.xmldb.services.CollectionManager;
import org.apache.xindice.tools.XMLTools;
import org.apache.xindice.xml.dom.DocumentImpl;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;

import java.util.Hashtable;

/**
 * AddCollection.java is designed to let the user create
 * new Collections and Nested Collections within the Database.
 *
 * @version CVS $Revision: 1.11 $, $Date: 2004/02/08 02:57:35 $
 */
public class AddCollection extends Command {

    /**
     * Creates collection
     */
    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        Collection tempcol = null;
        try {

            // Verify that that collection passed in is not null
            if (table.get(XMLTools.COLLECTION) != null && table.get(XMLTools.NAME_OF) != null) {

                // Get a Collection reference to pass on to individual commands
                String colstring = normalizeCollectionURI((String) table.get(XMLTools.COLLECTION),
                                                          (String) table.get(XMLTools.LOCAL));

                col = DatabaseManager.getCollection(colstring);

                if (col == null) {
                    System.out.println("ERROR : Collection not found!");
                    return false;
                }

                String newcol = (String) table.get(XMLTools.NAME_OF);

                // Create an instance of the collection manager and create the collection

                CollectionManager colman = (CollectionManager) col.getService("CollectionManager", XMLDBAPIVERSION);

                String colName = "";
                String parName = newcol;

                int idx = parName.lastIndexOf("/");

                if (idx != -1) {
                    colName = parName.substring(idx + 1);
                    parName = parName.substring(0, idx);
                } else if (idx == -1) {
                    colName = parName;
                }

                if (colName.equals("")) {
                    System.out.println("Cannot create a NULL collection");
                    return false;
                }

                Document doc = new DocumentImpl();

                Element colEle = doc.createElement("collection");
                colEle.setAttribute("name", colName);
                // FIXME Make this configurable
                colEle.setAttribute("compressed", "true");
                colEle.setAttribute("inline-metadata", "true");

                doc.appendChild(colEle);

                Element filEle = doc.createElement("filer");
                filEle.setAttribute("class", "org.apache.xindice.core.filer.BTreeFiler");
                if (table.containsKey(XMLTools.PAGE_SIZE)) {
                    filEle.setAttribute("pagesize", (String) table.get(XMLTools.PAGE_SIZE));
                }

                if (table.containsKey(XMLTools.MAX_KEY_SIZE)) {
                    filEle.setAttribute("maxkeysize", (String) table.get(XMLTools.MAX_KEY_SIZE));
                }

                colEle.appendChild(filEle);

                tempcol = colman.createCollection(newcol, doc);

                System.out.println("Created : " + table.get(XMLTools.COLLECTION) + "/" + newcol);
            } else {
                System.out.println("ERROR : Collection Context and New Collection name required");
            }

        } finally {
            // Release the collection objects
            if (col != null) {
                col.close();
            }
            if (tempcol != null) {
                tempcol.close();
            }
        }

        return true;
    }
}