/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: RetrieveDocument.java,v 1.10 2004/02/08 02:57:35 vgritsenko Exp $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;
import org.xmldb.api.modules.XMLResource;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Hashtable;

/**
 * RetrieveDocument.java is designed to let the user recall or
 * retrieve a Document from a specific Collection and save it to a new location.
 *
 * @version CVS $Revision: 1.10 $, $Date: 2004/02/08 02:57:35 $
 */
public class RetrieveDocument extends Command {

    public boolean execute(Hashtable table) throws Exception {

        Collection col = null;
        try {

            if (table.get(XMLTools.COLLECTION) != null) {
                // Create a collection instance
                String colstring = normalizeCollectionURI((String) table.get(XMLTools.COLLECTION),
                                                          (String) table.get(XMLTools.LOCAL));
                String docname = (String) table.get(XMLTools.NAME_OF);

                col = DatabaseManager.getCollection(colstring);
                // Make sure that the collection was found
                if (col == null) {
                    System.out.println("ERROR : Collection not found!");
                    return false;
                }

                if (table.get(XMLTools.NAME_OF) != null) {

                    XMLResource resource = (XMLResource) col.getResource(docname);
                    // Verify that we were able to find the document
                    if (resource == null) {
                        System.out.println("ERROR : Document not found!");
                        return false;
                    }

                    String documentstr = (String) resource.getContent();

                    if ((documentstr != null) && (table.get(XMLTools.FILE_PATH) != "")) {
                        try {
                            File file = new File((String) table.get(XMLTools.FILE_PATH));
                            // Create the directory structure if necessary
                            if (file.getParentFile() != null) {
                                file.getParentFile().mkdirs();
                            }

                            FileOutputStream out = new FileOutputStream(file);

                            System.out.println("Writing...");

                            out.write(documentstr.getBytes("utf-8"));
                            out.close();

                            System.out.println("Wrote file " + table.get(XMLTools.FILE_PATH));

                        } catch (IOException ie) {
                            System.out.println("ERROR : " + ie);
                            return false;

                        } catch (NullPointerException e) {
                            System.out.println("ERROR : " + e);
                            System.out.println("No file destination given");
                            return false;
                        }
                    } else {
                        // Send to stdout
                        System.out.println(documentstr);
                    }
                } else {
                    System.out.println("ERROR : Document Key required");
                }
            } else {
                System.out.println("ERROR : Collection context required");
            }

        } finally {
            // Release the collection object
            if (col != null) {
                col.close();
            }
        }

        return true;
    }

}

