/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: DirectoryClassLoader.java,v 1.6 2004/02/08 02:59:39 vgritsenko Exp $
 */

package org.apache.xindice.util;

import java.io.File;
import java.io.FileInputStream;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * DirectoryClassLoader reads classes relative to the
 * constructor-provided base directory. This class is typically used for loading
 * classes from a directory that isn't on the CLASSPATH.
 *
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 02:59:39 $
 */
public final class DirectoryClassLoader extends ClassLoader {

    private File directory = null;
    private Map cache = Collections.synchronizedMap(new HashMap());
    private Map dates = Collections.synchronizedMap(new HashMap());


    public DirectoryClassLoader(String directory) {
        this.directory = new File(directory);
    }

    private File getClassFile(String classname) {
        String filename = classname.replace('.', File.separatorChar) + ".class";
        return new File(directory, filename);
    }

    public boolean isModified(String classname) {
        Long value = (Long) dates.get(classname);
        if (value != null) {
            try {
                File file = getClassFile(classname);
                return file.lastModified() != value.longValue();
            } catch (Exception e) {
                return true;
            }
        }
        return false;
    }

    public Class loadClass(String classname, boolean resolve) throws ClassNotFoundException {
        try {
            Class c = (Class) cache.get(classname);
            if (c == null) {
                try {
                    File file = getClassFile(classname);
                    FileInputStream fis = new FileInputStream(file);
                    byte[] data = new byte[fis.available()];
                    fis.read(data);
                    fis.close();
                    c = defineClass(classname, data, 0, data.length);
                    dates.put(classname, new Long(file.lastModified()));
                } catch (Throwable t) {
                    c = findSystemClass(classname);
                }
                cache.put(classname, c);
            }
            if (resolve) {
                resolveClass(c);
            }
            return c;
        } catch (Exception e) {
            throw new ClassNotFoundException(e.toString());
        }
    }
}
