/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: Poolable.java,v 1.4 2004/02/08 02:59:39 vgritsenko Exp $
 */

package org.apache.xindice.util;

/**
 * Poolable is an interface that must be implemented by Objects that are
 * capable of being managed in a pooled fashion by Xindice.
 *
 * @see org.apache.xindice.util.ObjectPool
 * @version CVS $Revision: 1.4 $, $Date: 2004/02/08 02:59:39 $
 */
public interface Poolable {

    /**
     * setPool passes a reference to the originating ObjectPool for this
     * Object.  This will allow the Poolable Object to call back to the
     * ObjectPool in order to be reclaimed.
     *
     * @param pool The parent ObjectPool
     */
    void setPool(ObjectPool pool);

    /**
     * reclaim prompts the Poolable object to return itself to the
     * ObjectPool.  A Poolable implementation should perform any
     * necessary cleanup before calling pool.putObject to return
     * itself to the ObjectPool.
     */
    void reclaim();
}
