/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: NodeSource.java,v 1.7 2004/02/08 03:50:13 vgritsenko Exp $
 */

package org.apache.xindice.xml;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.data.Key;

/**
 * NodeSource encapsulates the source of a Document, including
 * its Collection reference and its Key.
 *
 * @version CVS $Revision: 1.7 $, $Date: 2004/02/08 03:50:13 $
 */
public final class NodeSource {

    public static final String SOURCE_NS = "http://xml.apache.org/xindice/Query";
    public static final String SOURCE_COL = "col";
    public static final String SOURCE_KEY = "key";
    public static final String SOURCE_COUNT = "count";
    public static final String SOURCE_MODIFIED = "modified";

    private Collection collection = null;
    private Key key = null;


    public NodeSource(Collection collection, Key key) {
        this.collection = collection;
        this.key = key;
    }

    public NodeSource(Collection collection) {
        this.collection = collection;
    }

    public Collection getCollection() {
        return collection;
    }

    public Key getKey() {
        return key;
    }

    public String getCanonicalName() {
        if (key != null) {
            return collection.getCanonicalDocumentName(key);
        } else {
            return collection.getCanonicalName();
        }
    }
}
