/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: SymbolTableSymbols.java,v 1.8 2004/02/08 03:50:13 vgritsenko Exp $
 */

package org.apache.xindice.xml;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.xindice.xml.dom.DOMParser;

import org.w3c.dom.Element;

/**
 * SymbolTableSymbols is class that represents the hard-coded definition
 * of a compressed symbol table.
 *
 * @version CVS $Revision: 1.8 $, $Date: 2004/02/08 03:50:13 $
 */
public final class SymbolTableSymbols extends SymbolTable {

    private static final Log log = LogFactory.getLog(SymbolTableSymbols.class);

    private static String SYMBOLS_DEFINITION
            = "<symbols>"
            + "   <symbol name=\"" + SYMBOLS + "\" id=\"0\" />"
            + "   <symbol name=\"" + SYMBOL + "\" id=\"1\" />"
            + "   <symbol name=\"" + NAME + "\" id=\"2\" />"
            + "   <symbol name=\"" + ID + "\" id=\"3\" />"
            + "   <symbol name=\"" + NSURI + "\" id=\"4\" />"
            + "</symbols>";

    private Element symbolsElem;

    private SymbolTableSymbols() {
        try {
            symbolsElem = DOMParser.toDocument(SYMBOLS_DEFINITION).getDocumentElement();
        } catch (Exception e) {
            if (log.isWarnEnabled()) {
                log.warn("ignored exception", e);
            }
        }
        streamFromXML(symbolsElem);
    }

    public static String getDefinition() {
        return SYMBOLS_DEFINITION;
    }

    public static SymbolTableSymbols getInstance() {
        return new SymbolTableSymbols();
    }
}

