/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: DocumentTypeImpl.java,v 1.4 2004/02/08 03:11:56 vgritsenko Exp $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.DocumentType;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

/**
 * DocumentTypeImpl
 *
 * @version CVS $Revision: 1.4 $, $Date: 2004/02/08 03:11:56 $
 */
public final class DocumentTypeImpl extends NodeImpl implements DocumentType {

    public DocumentTypeImpl() {
        super(null, true);
    }

    public short getNodeType() {
        return Node.DOCUMENT_TYPE_NODE;
    }

    /**
     * The name of DTD; i.e., the name immediately following the
     * <code>DOCTYPE</code> keyword.
     */
    public String getName() {
        return nodeName;
    }

    /**
     * A <code>NamedNodeMap</code> containing the general entities, both
     * external and internal, declared in the DTD. Duplicates are discarded.
     * For example in:&lt;!DOCTYPE ex SYSTEM "ex.dtd" [ &lt;!ENTITY foo
     * "foo"&gt; &lt;!ENTITY bar "bar"&gt; &lt;!ENTITY % baz "baz"&gt;]&gt;
     * &lt;ex/&gt;  the interface provides access to <code>foo</code> and
     * <code>bar</code> but not <code>baz</code>. Every node in this map also
     * implements the <code>Entity</code> interface.
     * <br>The DOM Level 1 does not support editing entities, therefore
     * <code>entities</code> cannot be altered in any way.
     */
    public NamedNodeMap getEntities() {
        return null;
    }

    /**
     * A <code>NamedNodeMap</code> containing  the notations declared in the
     * DTD. Duplicates are discarded. Every node in this map also implements
     * the <code>Notation</code> interface.
     * <br>The DOM Level 1 does not support editing notations, therefore
     * <code>notations</code> cannot be altered in any way.
     */
    public NamedNodeMap getNotations() {
        return null;
    }

    /**
     * The public identifier of the external subset.
     * @since DOM Level 2
     */
    public String getPublicId() {
        return null;
    }

    /**
     * The system identifier of the external subset.
     * @since DOM Level 2
     */
    public String getSystemId() {
        return null;
    }

    /**
     * The internal subset as a string.The actual content returned depends on
     * how much information is available to the implementation. This may
     * vary depending on various parameters, including the XML processor
     * used to build the document.
     * @since DOM Level 2
     */
    public String getInternalSubset() {
        return null;
    }
}

