/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: MetaTest.java,v 1.5 2004/02/08 03:56:47 vgritsenko Exp $
 */

package org.apache.xindice.core.meta;

import junit.framework.TestCase;
import org.apache.xindice.xml.TextWriter;
import org.apache.xindice.xml.dom.DocumentImpl;
import org.apache.xindice.xml.dom.DOMParser;
import org.w3c.dom.*;

/**
 * @author Dave Viner <dviner@apache.org>
 * @version CVS $Revision: 1.5 $, $Date: 2004/02/08 03:56:47 $
 */
public class MetaTest extends TestCase {

   /* make sure we can make 2 metadata objects that are identical */
   public void testMetaSimpleComparison() {
	    MetaData m1 = new MetaData(MetaData.UNKNOWN, "test1", 0, 0);
		MetaData m2 = new MetaData(MetaData.UNKNOWN, "test1", 0, 0);
		assertEquals(m1.toString(), m2.toString());		    
   }

   /* make sure we can make 2 metadata objects that are different */
   public void testMetaComplexCreation() {
		MetaData m1 = new MetaData(MetaData.UNKNOWN, "test1", 0, 0);
		MetaData m2 = new MetaData(MetaData.COLLECTION, "test1", 0, 0);
		assertFalse(m1.toString().equals(m2.toString()));
	}
	
	/* make sure we can get and set attributes */
	public void testMetaAttrs() {
		MetaData m1 = new MetaData(MetaData.UNKNOWN, "test1", 0, 0);
		m1.setAttribute("test", "cases");
		String s = (String)m1.getAttribute("test");
		assertEquals(s, "cases");
		
		s = (String)m1.getAttribute("not there");
		assertNull(s);
    }
	
	/* make sure we can get and set custom documents */
	public void testMetaCustomDocument() {
		MetaData m1 = new MetaData(MetaData.UNKNOWN, "test1", 0, 0);
		
		Document doc_init = m1.getCustomDocument();
		assertNull(doc_init);
		
		String cust = "<custom_xml>" +
				"<mycool>xml document that looks <like />"+
				"whatever i want</mycool>" +
				"</custom_xml>";
		Document doc = null;
		try {
			doc = DOMParser.toDocument(cust);
		} catch(Exception e) {
			fail("Can't parse xml document! "+e.getMessage());
		}
		m1.setCustomDocument(doc);
		
		Document doc2 = m1.getCustomDocument();
		assertEquals(TextWriter.toString(doc), TextWriter.toString(doc2));
	}
	
	/* make sure we can create a metadata object from xml
	   and make sure we can stream it back to xml without any changes */
	public void testMetaFromXml() {
		String xml = "<?xml version=\"1.0\"?>\n" +
			"<meta xmlns=\"http://apache.org/xindice/metadata\">" +
		    "<system type=\"doc\">" +
		    "<attr name=\"created\" value=\"0\" />" +
			"<attr name=\"modified\" value=\"0\" />" +
			"</system></meta>";
		Document doc = null;
		try {
		    doc = DOMParser.toDocument(xml);
		} catch (Exception e) {
			fail("Can't parse xml document! "+e.getMessage());
		}
		MetaData meta = new MetaData();
		meta.streamFromXML(doc.getDocumentElement(), true);
		Document doc2 = new DocumentImpl();
        doc2.appendChild(meta.streamToXML(doc2, true));
		assertEquals(TextWriter.toString(doc), TextWriter.toString(doc2));
	}
}
