/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * CVS $Id: IndexTest.java,v 1.6 2004/02/08 03:57:02 vgritsenko Exp $
 */

package org.apache.xindice.integration.client.basic;

import org.apache.xindice.integration.client.AbstractXmlDbClientTest;
import org.w3c.dom.Document;
import org.xmldb.api.base.XMLDBException;

import java.util.Arrays;
import java.util.Vector;

/**
 * @version CVS $Revision: 1.6 $, $Date: 2004/02/08 03:57:02 $
 * @author Vladimir R. Bossicard <vladimir@apache.org>
 */
public class IndexTest extends AbstractXmlDbClientTest {

    public void testCreateIndexer() throws Exception {
        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("goodindexer"));
        this.client.dropIndexer(TEST_COLLECTION_PATH, "goodindexer");
    }

    private String getIndexDef(String name) {
        return "<?xml version=\"1.0\"?>" +
               "<index class=\"org.apache.xindice.core.indexer.ValueIndexer\" name=\"" + name + "\" pattern=\"pattern\" />";
    }

    public void testCreateDuplicateIndexer() throws Exception {
        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("duplicate"));
        try {
            this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("duplicate"));
            fail();
        } catch (XMLDBException e) {
            // assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
        } finally {
            this.client.dropIndexer(TEST_COLLECTION_PATH, "duplicate");
        }
    }

    public void testCreateIndexerEmptyName() throws Exception {
        try {
            this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef(""));
        } catch (XMLDBException e) {
            // assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
            return;
        }
        fail();
    }

    public void testCreateIndexerNullDefinition() throws Exception {
        try {
            this.client.createIndexer(TEST_COLLECTION_PATH, (Document)null);
        } catch (XMLDBException e) {
            // assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
            return;
        }
        fail();
    }

    public void testCreateIndexerInvalidDefinition() throws Exception {
        try {
            this.client.createIndexer(TEST_COLLECTION_PATH,
                    "<?xml version=\"1.0\"?>" +
                    "<index class=\"org.apache.xindice.core.indexer.BlahIndexer\" name=\"blah\" pattern=\"blah\" />");
        } catch (XMLDBException e) {
            // assertTrue( e.getMessage().lastIndexOf( "No name specified" ) > 0 );
            return;
        }
        fail();
    }

    public void testDropIndexerTwice() throws Exception {
        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("droptwice"));
        this.client.dropIndexer(TEST_COLLECTION_PATH, "droptwice");

        // drop the newly created index
        try {
            this.client.dropIndexer(TEST_COLLECTION_PATH, "droptwice");
        } catch (XMLDBException e) {
            //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
            return;
        }
        fail();
    }

    public void testDropIndexerInvalidName() throws Exception {
        try {
            this.client.dropIndexer(TEST_COLLECTION_PATH, "");
        } catch (XMLDBException e) {
            //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
            return;
        }
        fail();
    }

    public void testDropIndexerNullName() throws Exception {
        try {
            this.client.dropIndexer(TEST_COLLECTION_PATH, null);
        } catch (XMLDBException e) {
            //assertTrue( e.getMessage().lastIndexOf( "Index Value Null" ) > 0 );
            return;
        }
        fail();
    }

    public void testListIndexers() throws Exception {
        String[] indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(0, indexes.length);

        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("index1"));
        indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(1, indexes.length);
        assertEquals("index1", indexes[0]);

        this.client.createIndexer(TEST_COLLECTION_PATH, getIndexDef("index2"));
        indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(2, indexes.length);
        Vector lst = new Vector(Arrays.asList(indexes));
        assertTrue(lst.contains("index1"));
        assertTrue(lst.contains("index2"));

        this.client.dropIndexer(TEST_COLLECTION_PATH, "index1");
        indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(1, indexes.length);
        assertEquals("index2", indexes[0]);

        this.client.dropIndexer(TEST_COLLECTION_PATH, "index2");
        indexes = this.client.listIndexes(TEST_COLLECTION_PATH);
        assertEquals(0, indexes.length);
    }
}
